@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2010-2012 Raphaël Barrois
+# Copyright (c) 2010-2013 Raphaël Barrois
 
 # Python3
 from __future__ import unicode_literals
 
-__version__ = '1.1.3'
+__version__ = '1.1.4'
 __author__ = "Raphaël Barrois <raphael.barrois+tdparser@polytechnique.org>"
 
 
@@ -14,9 +14,11 @@ from .topdown import (
 
     Parser,
 
-    ParserError, ParserSyntaxError,
+    Error, ParserError, InvalidTokenError, MissingTokensError,
 )
 
 from .lexer import (
     Lexer,
+
+    LexerError,
 )
